AES class

Wraps the AES Algorithm.

Implemented types

Constructors

AES(Key key, {AESMode mode = AESMode.sic, String? padding = "PKCS7"})

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → Key
final
mode → AESMode
final
padding → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decrypt(Encrypted encrypted, {IV? iv, Uint8List? associatedData}) → Uint8List
Decrypt encrypted value.
override
encrypt(Uint8List bytes, {IV? iv, Uint8List? associatedData}) → Encrypted
Encrypt bytes.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited